# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need Test::More ≥ 0.96 and Test::Warnings, so use bundled ones if we don't have them
%global test_more_lt096 %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.96) ? 1 : 0);' 2>/dev/null || echo 0)

# We need to use List::MoreUtils if our List::Util is too old
%global list_util_lt145 %(perl -MList::Util -e 'print (($List::Util::VERSION < 1.45) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-DateTime-Locale
Version:	1.14
Release:	1.0.cf.%{__distinit}%{__distvers}
Summary:	Localization support for DateTime.pm
# package itself is 'same terms as Perl'
# modules under DateTime/Locale/ are generated from data provided by the CLDR project
# tools/t/test-data contains CLDR data files under Unicode license
License:	(GPL+ or Artistic) and Unicode
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/DateTime-Locale/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DR/DROLSKY/DateTime-Locale-%{version}.tar.gz
Source1:	Test-More-and-Warnings.tar.gz
Patch0:		DateTime-Locale-1.07-old-List::Util.patch
BuildArch:	noarch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Dist::CheckConflicts) >= 0.02
BuildRequires:	perl(Exporter)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(List::MoreUtils)
BuildRequires:	perl(namespace::autoclean) >= 0.19
BuildRequires:	perl(Params::ValidationCompiler) >= 0.13
BuildRequires:	perl(Specio::Declare)
BuildRequires:	perl(Specio::Library::String)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(CPAN::Meta::Check) >= 0.011
BuildRequires:	perl(CPAN::Meta::Requirements)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Storable)
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Requires)
%if 0%{?fedora} >= 9 || 0%{?rhel} >= 6
BuildRequires:	perl(Test::Warnings)
%else
BuildRequires:	perl(parent)
%endif
BuildRequires:	perl(utf8)
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
DateTime::Locale is primarily a factory for the various locale subclasses. It
also provides some functions for getting information on all the available
locales.

%prep
%setup -q -n DateTime-Locale-%{version}

# We need to use List::MoreUtils if our List::Util is too old
%if %{list_util_lt145}
%patch0
%endif

# We need Test::More ≥ 0.96 and Test::Warnings, so use bundled ones if we don't have them
%if %{test_more_lt096}
tar xfz %{SOURCE1}
find inc/Test -type f >> MANIFEST
%endif

%build
# Use our local Test::More if necessary
[ -d inc/Test/ ] && export PERL5LIB=$(pwd)/inc

perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
# Use our local Test::More if necessary
[ -d inc/Test/ ] && export PERL5LIB=$(pwd)/inc

make test

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE LICENSE.cldr
%else
%doc LICENSE LICENSE.cldr
%endif
%doc Changes CONTRIBUTING.md README.md
%dir %{perl_vendorlib}/DateTime/
%{perl_vendorlib}/DateTime/Locale/
%{perl_vendorlib}/DateTime/Locale.pm
%{_mandir}/man3/DateTime::Locale.3*
%{_mandir}/man3/DateTime::Locale::*.3*

%changelog
* Mon Mar  6 2017 Paul Howarth <paul@city-fan.org> - 1.14-1.0.cf
- Update to 1.14
  - Fixed a regression bug where providing a locale's English name or native
    name to DateTime::Locale->load no longer worked (GH#13)
  - Codes with just a language and script code were not parsed correctly,
    leading to bugs in their data such that they did not report a script_code,
    nor did their name reflect the script, e.g. "bs-Latn" was just "Bosnian"
    instead of "Bosnian Latin"

* Mon Jan 30 2017 Paul Howarth <paul@city-fan.org> - 1.12-1.0.cf
- Update to 1.12
  - Rebuilt all locale data with CLDR 30.0.3, released on 2016-12-02

* Mon Jan  9 2017 Paul Howarth <paul@city-fan.org> - 1.11-2.0.cf
- Test::Warnings now available back to Fedora 9

* Mon Nov 14 2016 Paul Howarth <paul@city-fan.org> - 1.11-1.0.cf
- Update to 1.11
  - Switched from RT to the GitHub issue tracker

* Sat Oct 22 2016 Paul Howarth <paul@city-fan.org> - 1.10-1.0.cf
- Update to 1.10
  - Don't let warnings from other modules cause t/09version-check.t to fail
    (CPAN RT#118465)
`
* Tue Oct 11 2016 Paul Howarth <paul@city-fan.org> - 1.09-1.0.cf
- Update to 1.09
  - Rebuilt all locale data with CLDR 30, released on 2016-10-05

* Sun Sep 25 2016 Paul Howarth <paul@city-fan.org> - 1.08-1.0.cf
- Update to 1.08
  - Require namespace::autoclean 0.19+

* Sun Sep 18 2016 Paul Howarth <paul@city-fan.org> - 1.07-1.0.cf
- Update to 1.07
  - Replaced Params::Validate with Params::ValidationCompiler
  - Bump minimum required Perl to 5.8.4 from 5.8.1; this matches DateTime.pm
    itself
- Update patch for old distributions without recent List::Util

* Mon Jun 27 2016 Paul Howarth <paul@city-fan.org> - 1.05-1.0.cf
- Update to 1.05
  - Instead of using the DATA handle to get at as-yet-unloaded locale data in
    DateTime::Locale::Data, we now read the raw data into memory once, and use
    eval to turn it into Perl data structures as a particular locale is
    requested, which may fix a problem where reading from the DATA handle
    somehow returned the wrong chunk of data (or overlapped multiple locales);
    the downside is that loading DateTime::Locale now uses an additional 4MB of
    memory on my system, regardless of how many individual locales are
    instantiated (GH#3)

* Sun Jun 19 2016 Paul Howarth <paul@city-fan.org> - 1.04-1.0.cf
- Update to 1.04
  - Replaced List::MoreUtils with List::Util
- Add patch to revert to List::MoreUtils when List::Util is too old
- BR: perl-generators where available
- Simplify find command using -delete

* Sun Mar 27 2016 Paul Howarth <paul@city-fan.org> - 1.03-1.0.cf
- Update to 1.03
  - Rebuilt all locale data with CLDR 29, released on 2016-03-19

* Thu Dec 10 2015 Paul Howarth <paul@city-fan.org> - 1.02-1.0.cf
- Update to 1.02
  - Make the DateTime::Locale->load method accept a locale in any non-canonical
    casing, such as "en-us" (CPAN RT#110244)

* Sun Nov  8 2015 Paul Howarth <paul@city-fan.org> - 1.01-1.0.cf
- Update to 1.01
  Enhancements
  - This release uses the locale data from CLDR version 28; the last major
    update of the locale data used CLDR 1.7.1, released in 2009, so this is a
    big change - many things have changed in terms of locale data
  - Some locales are no longer available because they are not in the CLDR data
  - The CLDR data no longer includes default date and time format lengths; this
    is now "medium" for every locale, simply to provide some level of backwards
    compatibility
  - Loading DateTime::Locale itself is now quite a bit faster; the whole locale
    registration system has been removed entirely, except for custom locales
    (CPAN RT#78794)
  - A long-standing issue with the Austrian locale not using the Austrian name
    for January has been fixed (CPAN RT#52337)
  Backwards Incompatibilities
  - This is a big new release, and includes a number of backwards-incompatible
    changes, though most users should be unaffected by this change; if you only
    use this module via DateTime.pm, you are unlikely to notice any changes
    other than changes to the locale data
  - The old API deprecated since 0.40 has been removed (almost) entirely
  - We now refer to things as "code" in the docs and method names where we used
    to call them ids; this includes locale, language, script, territory, and
    variant codes - this is more in line with the various ISO standards and the
    CLDR packages
  - All the $locale->*_id methods (including $locale->id) are deprecated; use
    the relevant $locale->*_code method instead
  - The canonical form of the locale codes now uses dashes (-) instead of
    underscores (_); loading a locale with an underscore in the name (e.g.
    en_US) still works
  - The way that locale data is packaged has changed quite a bit; we no longer
    package each locale in its own class: instead, all locale data is in a
    single module (mostly in a __DATA__ section) and loaded into memory as
    needed, so if you have any code that checks $locale->isa, that code may
    break
  - Locales are no longer subclasses of DateTime::Locale::Base; this module is
    still included in the distribution in case someone has a custom locale that
    inherits from this module, but this module will go away in a future release
  - The "ii-*" aliases for the "he-*" locales have been removed
  - The "no-*" aliases for the "nn-*" locales have been removed
  - The value of $locale->code no longer reflects the value passed to
    DateTime::Locale->load; this only affects aliases and non-canonical forms of
    the code, e.g. if you load "en_US" then $locale->code will return "en-US"
    and if you load "C" or "POSIX" the returned code will be "en-US-POSIX"
  - All of the documentation related to creating aliases and registering custom
    locales has been removed; all of these methods still work, but I don't think
    this system got much use, so I don't want to emphasize it in the docs (but
    let me know if you are using this and want to see these docs restored)
- Bundle Test::More and Test::Warnings for use with old distributions

* Mon Sep 28 2015 Paul Howarth <paul@city-fan.org> - 0.92-1.0.cf
- Update to 0.92 (no changes)

* Mon Jun 29 2015 Paul Howarth <paul@city-fan.org> - 0.46-3.0.cf
- Perl 5.22 rebuild

* Fri May 22 2015 Paul Howarth <paul@city-fan.org> - 0.46-1.0.cf
- Update to 0.46
  - Fixed handling of C locales like "C.UTF-8"; passing these to
    DateTime::Locale->load would cause a warning followed by an exception, but
    all "C" locales should be special-cased as an alias of en-US-POSIX
    (CPAN RT#104574)
- Switch to ExtUtils::MakeMaker flow
- Classify buildreqs by usage

* Fri Sep 12 2014 Paul Howarth <paul@city-fan.org> - 0.45-22.0.cf
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 0.45-21.0.cf
- Perl 5.18 rebuild

* Tue Jul  2 2013 Paul Howarth <paul@city-fan.org> - 0.45-20.0.cf
- DateTime::LocaleCatalog has been renamed to DateTime::Locale::Catalog
  and cannot be loaded, which broke the POD coverage test

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 0.45-19.0.cf
- BR: perl(base), perl(Carp), perl(File::Spec), perl(lib) and perl(Storable)
- Update UTF8 patch to fix broken POD test
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Don't need to run test suite with LC_ALL=C

* Fri Aug 19 2011 Paul Howarth <paul@city-fan.org> - 0.45-18.0.cf
- Unbundled from perl-DateTime
